# pynoddgcs

Utilities for working with [NOAA NODD](https://www.noaa.gov/information-technology/open-data-dissemination) GCS in python.
  These utilities are intended as [opinionated](https://en.wikipedia.org/wiki/Convention_over_configuration) tools for interacting with GCS for the purpose of [findable, accessible, interoperable and reusable](https://en.wikipedia.org/wiki/FAIR_data) open [science](https://en.wikipedia.org/wiki/Open_science).
  By adopting common conventions for data dissemination, we not only reduce the learning curve to comprehending dataset layout, but we empower automation for combining data and further dissemination, e.g. through [NCEI](https://www.ncei.noaa.gov/access/search/index).

# Installation

`pip install pynoddgcs`

# Contributing

We would love to have your contributions that improve current functionality, fix bugs, or add new features.  See [the contributing guidelines](CONTRIBUTING.md) for more info.

# Disclaimer

This repository is a scientific product and is not official communication of the National Oceanic and
Atmospheric Administration, or the United States Department of Commerce. All NOAA GitHub project
code is provided on an ‘as is’ basis and the user assumes responsibility for its use. Any claims against the
Department of Commerce or Department of Commerce bureaus stemming from the use of this GitHub
project will be governed by all applicable Federal law. Any reference to specific commercial products,
processes, or services by service mark, trademark, manufacturer, or otherwise, does not constitute or
imply their endorsement, recommendation or favoring by the Department of Commerce. The Department
of Commerce seal and logo, or the seal and logo of a DOC bureau, shall not be used in any manner to
imply endorsement of any commercial product or activity by DOC or the United States Government.
